# ifcbUTOPIA Data Pipeline Tools

This repository contains a collection of tools to streamline the process of converting raw IFCB data to CNN-labeled and validated datasets. These functions are contained in the `utopia_pipeline_tools` folder.

Currently, the toolkit is under construction, but it can be installed to a local machine by cloning this repository, navigating to the root folder in anaconda, and typing `pip install .`

Notebooks to help users navigate the data pipeline will be added soon, and I aim to set up the toolkit to be installable via pip without needing to clone the repo. 